@@ -7,45 +7,65 @@
 #' @param form a formula describing the x and y variables as y ~ x.
 #' @param data a data.frame object.
 #' @param type the type of plot. Currently, only "n", "b", "p", "l" are supported. See \code{\link{plot}} for more details.
-#' @param col color of the visual elements. 
+#' @param color column used to define the colors used to fill the bars. Default is NULL.
+#' @param isString a character is expected for \code{data} and \code{color} if \code{TRUE}. It is useful for programming.
 #' 
 #' @seealso \code{\link{plot}}
 #' 
 #' @export
 #' 
 #' @examples
-#' \donttest{obj <- RIGHT(plot(conc ~ Time, Theoph, type = "b"), Theoph)}
-#' \donttest{print(obj)}
-plot_RIGHT <- function(form, data, type = "b", col = NULL) {
+#' \donttest{
+#' obj <- RIGHT(plot(conc ~ Time, Theoph, type = "b", color = Subject))
+#' print(obj)
+#' }
+plot_RIGHT <- function(form, data, type = "b", color = NULL,
+                       isString = FALSE) {
+
+  # @param col color used for all the visual elements. color option overrides \code{col} option.
+  col <- NULL # TEMPORARY
+  
+  ## ---
+  ## Take strings if asked:
+  ## ---
+  
+  argArray <- as.list(match.call())
+  
+  if (!isString) {
+    
+    data <- if (is.null(argArray$data)) NULL else as.character(argArray$data)
+    color <- if (is.null(argArray$color)) NULL else as.character(argArray$color)
+    
+  } # if
   
   ## ---
   ## Check input arguments:
   ## ---
   
-  # Make sure that data exists:
-  argArray <- as.list(match.call())
-  
-  dataAttr <- attr(data, "char")
-  if (!is.null(dataAttr) && dataAttr == TRUE) {
-    dataName <- data
-  } else {
-    dataName <- as.character(argArray$data)
-  } # if
-  checkDataName(dataName)
-
   # get is necessary in case a character string is given for data:
-  dataArray <- get(dataName, envir = parent.frame())
+  if (!exists(data, envir = parent.frame())) {
+    stop(data, " does not exist.")
+  } # if
+  dataArray <- get(data, envir = parent.frame(), inherits = TRUE)
   
   # Check whether the columns exist:
   # CHECK (junghoon): is there a way to check whether form is a formula?
   axisName <- checkFormula_xy(form) 
-  checkAxisName(axisName$x, dataArray)
-  checkAxisName(axisName$y, dataArray)
+  checkColumnName(axisName$x, dataArray)
+  checkColumnName(axisName$y, dataArray)
+  
+  # Check color option:
+  checkColumnName(color, dataArray)
+  
+  # col option is checked by points_RIGHT() or line_RIGHT().
   
   ## ---
   ## Create an axis:
   ## ---
   
+  # Keep name of the data object:
+  .RIGHT$nameArray <- append(.RIGHT$nameArray, data)
+
   # Increment the number of axes:
   .RIGHT$numAxis <- .RIGHT$numAxis + 1
   
@@ -58,8 +78,9 @@ plot_RIGHT <- function(form, data, type = "b", col = NULL) {
   .RIGHT$scriptArray <- append(.RIGHT$scriptArray,
                                paste0("var axis", .RIGHT$numAxis,
                                       " = new Axis(", .RIGHT$numAxis, 
-                                      ", ", dataName,
-                                      ", '", axisName$x, "', '", axisName$y, "', {});"))
+                                      ", ", data,
+                                      ", '", axisName$x, "', '", axisName$y, 
+                                      "', ", createObject(legend = color, alwaysObject = TRUE), ");"))
   
   ## ---
   ## Plot lines if necessary:
@@ -67,7 +88,8 @@ plot_RIGHT <- function(form, data, type = "b", col = NULL) {
 
   # CHECK (junghoon): refine this to support type == "c" as well.
   if (type == "l" || type == "b") {
-    lines_RIGHT(form, char(dataName), col = col)
+#     lines_RIGHT(form, data, col = col, isString = TRUE)
+    lines_RIGHT(form, data, isString = TRUE)
   } # if
   
   ## ---
@@ -75,7 +97,8 @@ plot_RIGHT <- function(form, data, type = "b", col = NULL) {
   ## ---
   
   if (type == "p" || type == "b") {
-    points_RIGHT(form, char(dataName), col = col)
+#     points_RIGHT(form, data, col = col, isString = TRUE)
+    points_RIGHT(form, data, isString = TRUE)
   } # if
   
   invisible()
