@@ -1,7 +1,7 @@
 context("Test boxplot_RIGHT.R")
 
 setRIGHT(libDir_RIGHT = ".", 
-         nameArray = "Theoph",
+         nameArray = "dummy",
          divArray = c(),
          scriptArray = c(),
          numAxis = 0,
@@ -13,16 +13,19 @@ test_that("data.frame object should exist", {
   temp <- get(".RIGHT", envir = asNamespace("RIGHT"))
   expect_identical(temp$numAxis, 0)
   expect_identical(temp$numBox, 0)
+  expect_identical(temp$nameArray, "dummy")
+  expect_false(any(file.path(temp$libDir_RIGHT, "box.js") %in% temp$sourceArray))
   
 }) # test_that
 
 test_that("Column name should exist", {
   
   expect_error(boxplot_RIGHT(conc1 ~ Subject1, Thoeph))
-  # expect_error(boxplot_RIGHT(char("conc1 ~ Subject1"), Thoeph)) # CHECK (junghoon)
   temp <- get(".RIGHT", envir = asNamespace("RIGHT"))
   expect_identical(temp$numAxis, 0)
   expect_identical(temp$numBox, 0)
+  expect_identical(temp$nameArray, "dummy")
+  expect_false(any(file.path(temp$libDir_RIGHT, "box.js") %in% temp$sourceArray))
   
 }) # test_that
 
@@ -32,6 +35,7 @@ test_that("Check script generation", {
   temp <- get(".RIGHT", envir = asNamespace("RIGHT"))
   expect_identical(temp$numAxis, 1)
   expect_identical(temp$numBox, 1)
+  expect_identical(temp$nameArray, c("dummy", "Theoph"))
   expect_identical(temp$divArray, '<div id="container1" oncontextmenu="return false;"></div>')
   expect_identical(temp$scriptArray, 
                    c("var boxObj1 = new MakeBoxObj(Theoph, 'Subject', 'conc', {});",
@@ -40,3 +44,7 @@ test_that("Check script generation", {
   expect_true(any(file.path(temp$libDir_RIGHT, "box.js") %in% temp$sourceArray))
   
 }) # test_that
+
+test_that("Check isString option:", {
+  # CHECK (junghoon)
+})
