@@ -1,7 +1,7 @@
 context("Test pie_RIGHT.R")
 
 setRIGHT(libDir_RIGHT = ".",
-         nameArray = "Theoph",
+         nameArray = "dummy",
          divArray = c(),
          scriptArray = c(),
          numAxis = 0,
@@ -13,16 +13,19 @@ test_that("data.frame object should exist", {
   temp <- get(".RIGHT", envir = asNamespace("RIGHT"))
   expect_identical(temp$numAxis, 0)
   expect_identical(temp$numPie, 0)
+  expect_identical(temp$nameArray, "dummy")
+  expect_false(any(file.path(temp$libDir_RIGHT, "pie.js") %in% temp$sourceArray))
   
 }) # test_that
 
 test_that("Column name should exist", {
   
   expect_error(pie_RIGHT(Subject1, Thoeph))
-  # expect_error(pie_RIGHT(char("Subject1"), Thoeph)) # CHECK (junghoon)
   temp <- get(".RIGHT", envir = asNamespace("RIGHT"))
   expect_identical(temp$numAxis, 0)
   expect_identical(temp$numPie, 0)
+  expect_identical(temp$nameArray, "dummy")
+  expect_false(any(file.path(temp$libDir_RIGHT, "pie.js") %in% temp$sourceArray))
   
 }) # test_that
 
@@ -32,6 +35,7 @@ test_that("Check script generation", {
   temp <- get(".RIGHT", envir = asNamespace("RIGHT"))
   expect_identical(temp$numAxis, 1)
   expect_identical(temp$numPie, 1)
+  expect_identical(temp$nameArray, c("dummy", "Theoph"))
   expect_identical(temp$divArray, '<div id="container1" oncontextmenu="return false;"></div>')
   expect_identical(temp$scriptArray, 
                    c("var pieObj1 = new ddply(Theoph, ['Subject'], {});",
@@ -39,4 +43,8 @@ test_that("Check script generation", {
                      "var pie1 = new Pie(axis1, pieObj1, 'Subject', 'frequency', {});"))
   expect_true(any(file.path(temp$libDir_RIGHT, "pie.js") %in% temp$sourceArray))
   
-}) # test_that
\ No newline at end of file
+}) # test_that
+
+test_that("Check isString option:", {
+  # CHECK (junghoon)
+})
